@@ -33,9 +33,8 @@ def dustjs(parser, token):
 
     """
     bits = token.contents.split()
-    if len(bits) not in [2, 3]:
+    if len(bits) != 2:
         raise template.TemplateSyntaxError(
-            "'dustjs' tag takes either (1) one argument: the name/id of "
-            "the template, or (2)  two arguments: the name of a subdirectory "
-            "to search and a regular expression of files to search for")
+            "'dustjs' tag takes either one argument: the name/id of "
+            "the template, or a pattern matching a set of templates.")
     return DustJSNode(*bits[1:])
